## Capabilities

This service can be used to:

- [ ] stat
- [ ] read
- [ ] write
- [ ] create_dir
- [ ] delete
- [ ] copy
- [ ] rename
- [ ] list
- [ ] presign
- [ ] blocking

## Configuration

## Example
